Re-Enable my root Account

on February 11, 2010

Root Account is disabled - see Account Administrator

When your HP-UX system is in the more secure "trusted system" mode, your account is automatically disabled after you have entered your password incorrectly 3 times in a row. At this point, even if you enter the correct password, you will not be allowed access into the account.

There are a few options to re-enable the account:

  • If you have access to the system console you can login using the root account from the console (this will automatically re-enable the account). Even when the account is disabled, login from the console will be allowed by default.
  • If you have another root account on the system, you can login using that account and reset the disabled user account using SAM.
To re-enable a disabled user account on the system using SAM:
  1. Select the “Accounts for users and groups” section.
  2. Select “users.”
  3. Select the user account that is disabled.
  4. With the disabled user account selected, go to the top of the screen and select “Actions.”
  5. Select “Reactivate” to reactivate the disabled account.
Note: Very important thing that u have to remember, when giving a password DON'T GIVE "@" CHARACTER IN PASSWORD. By mistakenly if any body uses the "@" character in password then use "\" before @ Symbol.

EX:If your Present Password is "3N%@Bb!8" then use this password "3N%\@Bb!8" after login into console user. 100% it will work
The @ character is the problem. It is the default cancel-entry character, just like # is the default backspace character. These defaults are leftover from the days of teletypewriters. It doesn't matter what OS you use, there will be special characters that you must avoid. Just stay away from the special chars across the top of your keyboard.

IGNITE BACKUP

on October 23, 2009

INTRODUCTION TO HP IGNITE-UX

HP-UX have a software to backup the OS called “Ignite”. It bundled with OS installed. The easy way to make a OS backup is using tape data cartridge. Just plug the tape and run command “make_tape_recovery -AI”. To restore OS using recovery tape

Ignite-UX is an HP-UX 10.x, 11.0, and 11i product, including 11i v1.6 which supports Itanium Processor Family (IPF) systems, that facilitates installing and configuring HP-UX systems. Ignite-UX releases are available to install the HP-UX 10.01, 10.10, 10.20, 11.0 and 11i releases on client systems.

You will need the following to install an Ignite-UX server

  • Computer - A series 700/800/Itanium Based Processor System running HP-UX 10.0 10.10 10.20 11.0 11i.
  • Memory - Ignite -UX requires 64MB Min. on each server and client.
  • Source Device - Make sure that your system has an appropriate source Device (ULT Drive) has physically attached to server. And ensure that drive heads are clean
  • Ensure that a active SCSI port must be there to attach tape ULT drive
  • An additional X11 display server. So that displkay can be redirected to another X-windows system by setting the DISPLAY environment variable. For example, in the Korn Sehll or Posix Shell use the following command
  • export DISPLAY=:0.0
  • Client and Server must be on the same subnet if you plan to do the initial boot of the client over the network.
  • Ignite UX Bundle

Identifying the source Bundle / Depot for Ignite UX Software

you can determine the source Bundle/Depot used to install Ignite-UX by using the follwing commands:

# swlist | grep -i ignite
# swlist -a install source -l bundle

Verify Hardware path

Identify the device which is use for IGNITE backup. Use proper Device to take IGNITE backup

# ioscan -funC tape


Creating a Ignite-UX recovery Tape:

Using make_tape_recovery: The Ignite-UX server's make_tape_recovery command creates a bootable recovery tape for an LVM or whole disk file system while it is up and running. When a system has a logical volume layout, the recovery tape will only include data from the root volume group, plus data from any non-root volume group containing the /usr directory. You can run make_tape_recovery either on the Ignite-UX server or locally on the system from which you are trying to make a recovery tape.
Note: This is not recommended because Ignite-UX is not an Backup Tool. Backup other VGs with other backup utilities such as fbackup, tar, etc.

Creating a make_tape_recovery tape - Command Line Examples

Backing up only essential core OS files using the default device file /dev/rmt/0mn

# /opt/ignite/bin/make_tape_recovery

Note: make_tape_recovery will check if there are configuration files from previously saved archives. If no configuration files exist that have different settings, only a core OS (essential files) will be backed up. /opt/ignite/recovery/mnr_essentials lists the files and directories that are considered essential.

To create the bootable recovery tape, enter:

Backing up the complete root VG using the default device file /dev/rmt/0mn

# /opt/ignite/bin/make_tape_recovery -Av -C -d /dev/rmt/0m

Options are explained below

-A: Based on the files that are specified for inclusion, this option identifies the disk(s) and/or VG(s) that contain these files and includes all files from the disk(s)/VG(s) in the archive. If no further files are specified for inclusion, the default essentials file list /opt/ignite/recovery/mnr_essentials is used for specifying the included files.

-v: Verbose mode, error and process logs will be displayed.

Backing up the complete root VG using a non-default device file

# /opt/ignite/bin/make_tape_recovery -Av –a /dev/rmt/c6t0d1BESTn


Verifying the make_tape_recovery Tape Looking up the log files

If make_tape_recovery was run locally, look up the log files at
/var/opt/ignite/recovery/.

How to set LAN Speed to Auto negotiable

on October 20, 2009

In HP - UX we can change LAN Speed in Two ways one is temporarily and second is permanently.

For temporary base just use this command at command prompt

# lanadmin -X auto_on 0 --- Where 0 is PPA Number of NIC
This command does not need any reboot and this will work up to next reboot of the system.

For permanent base you have to change the script on
hpigelanconf file and this file located at /etc/rc.config.d and find the following text

HP_IGELAN_INTERFACE_NAME[0]=lan0
HP_IGELAN_STATION_ADDRESS[0]=
HP_IGELAN_SPEED[0]=100fd
HP_IGELAN_MTU[0]=1500
HP_IGELAN_FLOW_CONTROL[0]=1
HP_IGELAN_AUTONEG[0]=0
HP_IGELAN_SEND_COAL_TICKS[0]=150
HP_IGELAN_RECV_COAL_TICKS[0]=0
HP_IGELAN_SEND_MAX_BUFS[0]=10
HP_IGELAN_RECV_MAX_BUFS[0]=1
HP_IGELAN_VMTU[0]=0
HP_IGELAN_SEND_CKO[0]=
HP_IGELAN_RECV_CKO[0]=
HP_IGELAN_DIAG_THRESH[0]=

and made the changes at the line HP_IGELAN_SPEED[0]=auto_on
This will fix the issue with LAN speed going to 100fd after reboot.

Backup and Recover Data to Tape Device

on September 19, 2009

FBACKUP / FRECOVER


HP-UX offers various commands just like any other UNIX system to backup file system, data and applications such as

a] dump / restore command (HFS filesystem only)

b] vxdump / vxrestore (vxfs filesystem only)

c] cpio command

d] fbackup / frecover command

e] dd command

f] tar command

g] make_net_recovery or make_tape_recovery commands


HP-UX Tape device names

First device will have name such as /dev/rmt/0m, /dev/rmt/1m and so on.
  1. Raw magnetic tape interface - /dev/rmt/*
  2. Default tape interface - /dev/rmt/0mnb

HP-UX Tape - mt ~ manipulating program

mt command winds the tape in the requested direction (forward or backward), stopping after the specified count EOF marks or records are passed. If count is not specified, one is assumed. Each EOF mark counts as one record. When winding backwards, the tape always stops at the BOT marker, regardless of the number remaining in count.See mt command man page for more information. For example, Rewind the tape associated with the device file /dev/rmt/0mnb:
# mt -f /dev/rmt/0mnb rew


How do I backup data with fbackup command?

Backup /data directory to /dev/rmt/0m, enter:
# fbackup -i /data -I index.data -f /dev/rmt/0m
Where,

  • -i /data : Backup /data directory. There is no limit on how many times the -i option can be specified i.e. -i /data -i /home -i /path/to/something
  • -I index.data : index.data specifies the name of the on-line index file to be generated. It consists of one line for each file backed up during the session. Each line contains the file size, the volume number on which that file resides, and the file name. If the -I option is omitted, no index file is generated.
  • -f /dev/rmt/0m : Specify tape device name
  • -e /tmp : Exclude /tmp from backup
  • -g /var/adm/fbackupfiles/hporabox11.backup.list.txt : File that contains a list of files / dirs to be included / excluded from the tape backup
  • -u : Update the database of past backups so that it contains the backup level, the time of the beginning and end of the session, and the graph file used for this fbackup session. Only use this if you are using -g /path/to/file option.

Using the normal tape location to do a full backup, insert a new tape and enter:
# fbackup -f /dev/rmt/0m -i -v
Using the normal tape location to do a full backup but exclude /tmp and /cdrom /nfs directories, insert a new tape and enter:
# fbackup -f /dev/rmt/0m -i / -e /tmp -e /cdrom -e /nfs -v
You can also create a text file that contains a list of all files and directories to be included or excluded from the backup. For example, backup full file system but exclude /tmp, /cdrom and /nfs, enet:
# cd /var/adm/fbackupfiles
# vi hporabox11.backup.list.txt

Append following list
i /
e /tmp
e /nfs
e /cdrom

Save and close the file. To backup enter,
# fbackup -f /dev/rmt/0m -g /var/adm/fbackupfiles/hporabox11.backup.list.txt -v


How do I perform full and incremental backups?

The -0-9 option used to specify backup level. This single-digit number is the backup level. Level 0 indicates a full backup. Higher levels are generally used to perform incremental backups. When doing an incremental backup of a particular graph at a particular level, the database of past backups is searched to find the date of the most recent backup of the same graph that was done at a lower level. If no such entry is found, the beginning of time is assumed. All files in the graph that have been modified since this date are backed.
First, perform full backup, enter:
# fbackup -f /dev/rmt/0m -u -0 -g /var/adm/fbackupfiles/hporabox11.backup.list.txt -v
To perform incremental backup, enter:
# fbackup -f /dev/rmt/0m -u -1 -g /var/adm/fbackupfiles/hporabox11.backup.list.txt -v


How do I view contents of an fbackup tape?

Type the following command:
# frecover -f /dev/rmt/0m -x -N -v


How do I backup data with frecover command?

To restore all files and directories from tape, enter:
# frecover -f /dev/rmt/0m -r -v
To restore selected files or directories use -i /path option. For example, just restore /home/vivek directory, enter:
# frecover -f /dev/rmt/0m -x -v -i /home/vivek

Where,

  • -r : Recovery all data from tape
  • -x : Extracted / recover selected files / dires only specified by -i option
  • -i /path/to/file : Recover only this file or directory
  • -v : Verbose output

How do I verify tape backup?

The -N option (no recovery) prevent frecover from actually recovering any files onto disk, but read the backup as if it was, in fact, recovering the data from the backup, producing the same output that it would on a normal recovery. This option is useful for verifying backup media contents in terms of validity (block checksum errors are reported), and contents (a listing of files can be produced by using the -N and -v options together). Note that the listing of files produced with the -N and -v options requires the reading of the entire backup, but is therefore a more accurate reflection of the backup's contents than the index stored at the beginning of the backup (which was created at the start of the backup session, and is not changed during the course of the backup).
# frecover -f /dev/rmt/0m -N


Tools Used for Performance Monitoring

on August 31, 2009

HP-UX has a number of tools that are bundled with the operating system. Additional sophisticated. Tools can be purchased separately. The bundled tools usually work in text mode. Some of these utilities are listed here.

The iostat command is used to monitor I/O activity for disk drives.

# iostat

device bps sps msps
c0t6d0 105 10.8 1.0
c0t5d0 0 0.0 1.0

device
Shows the actual disk device for which the report is given.
bps Shows kilobytes transferred per second to/from the device.
sps Lists the number of seeks per second.
msps The time in milliseconds per average seek.

The vmstat command is used to monitor activity of virtual memory.

Virtual memory statistics are displayed using the vmstat command. It displays information about processes, page faults, memory, and CPU as shown here. (The output is formatted to fit onto the page.)

# vmstat -n


VM

memory page faults
avm free re at pi po fr de sr in sy cs
2275 44047 2 0 0 0 1 0 0 106 88 33
CPU
cpu procs
us sy id r b w
0 0 99 0 0 0

The -n option is used with the command to improve the format of the output.

avm
Active virtual memory. These are the pages that have been assigned to some processes.
free Free pages. A number of columns are present under the page subheading.

re
Page reclaims. A large number shows a memory shortage.
at Address translation faults.
pi Pages paged in.
po Pages paged out.
fr Pages freed per second.
de Anticipated short term memory shortfall.
sr Pages scanned by clock algorithm, per second.
The faults subheading shows trap and interrupt rate averages per second over the least 5 seconds.

in
Device interrupts per second.
sy System calls per second.
cs CPU context switch rate.
The CPU part of the output has been divided into two subparts, cpu and procs. The columns under the cpu subheading show CPU utilization.

us
User time for normal and low-priority processes.
sy System time.
id CPU idle time.
An explanation of the different fields under the procs subheading is as given here.

r
The process is in run queue.
b Number of processes blocked for some resource.
w It shows runable but swapped out from the main memory.

The netstat and lanadmin commands are used to monitor network activity such as incoming and outgoing network traffic, use of protocols, IP addresses assigned to interface adapters.

The top utility is used to monitor processes that are utilizing more CPU time. Processes are listed in a sorted form. Percentage of CPU idle time is also displayed. This utility also shows some
information about real and virtual memory.

#top -s1


System: apmbdb01 Mon Aug 31 22:23:21 2009
Load averages: 0.13, 0.17, 0.23
206 processes: 184 sleeping, 21 running, 1 zombie
Cpu states:
CPU LOAD USER NICE SYS IDLE BLOCK SWAIT INTR SSYS
0 0.10 2.0% 0.0% 3.2% 94.8% 0.0% 0.0% 0.0% 0.0%
1 0.15 9.2% 0.0% 9.6% 81.2% 0.0% 0.0% 0.0% 0.0%
--- ---- ----- ----- ----- ----- ----- ----- ----- -----
avg 0.13 5.6% 0.0% 6.4% 88.0% 0.0% 0.0% 0.0% 0.0%

Memory: 4406476K (2952932K) real, 4761636K (3231796K) virtual, 1736900K free Page# 1/18

CPU TTY PID USERNAME PRI NI SIZE RES STATE TIME %WCPU %CPU COMMAND
1 ? 4296 oracle 148 20 3418M 23828K sleep 0:17 10.40 10.38 oracleAPMBPROD
1 ? 5238 root 154 20 11980K 1408K sleep 0:24 9.23 9.22 bma
0 ? 5237 root 154 20 14032K 1752K sleep 0:04 2.14 2.13 bma
1 ? 4286 oracle 154 20 105M 37992K sleep 0:06 1.16 1.16 rman
1 ? 52 root 152 20 3744K 3328K run 13:25 0.61 0.61 vxfsd
1 ? 1409 root 152 20 174M 67656K run 3:57 0.30 0.30 cimserver
1 ? 12683 root -27 20 47412K 39592K run 16:44 0.29 0.29 cmcld
0 ? 1782 root 152 20 112M 17004K run 0:59 0.14 0.14 vxsvc
0 ? 5318 oracle 154 20 3445M 52140K sleep 0:00 0.17 0.13 ora_lns2_APMBPROD
0 ? 453 root 152 20 8068K 2832K run 1:05 0.12 0.12 utmpd
0 ? 1402 root 152 20 25416K 5548K run 0:06 0.12 0.12 rpcd

A brief explanation of the columns in the process area is given below.
CPU This is the first column, which is not shown in Figure 25-1. It is present on systems with multiple

CPU
s. This represents a CPU number on which the process is being executed.
TTY The terminal used by the process.
PID Process ID.
USERNAME Name of the owner of the process.
PRI Process priority.
NI Nice value.
SIZE Total size of the process in memory.
RES Resident size of the process. This is an approximation.
STATE Current state of the process.
TIME CPU time consumed by the process.
%WCPU Weighted CPU percentage utilization by the process.
%CPU Raw CPU percentage utilization by the process.
COMMAND Name of the command that started the process.

The System Activity Reporter (sar) shows a number of kernel parameters and CPU utilization.

# sar -u 1 5


HP-UX hp0 B.11.00 A 9000/839 11/29/99
12:27:53 %usr %sys %wio %idle
12:27:54 1 1 0 98
12:27:55 0 0 0 100
12:27:56 0 0 0 100
12:27:57 0 0 0 100
12:27:58 0 0 0 100

Average 0 0 0 100

#sar -Mu 2 10
#sar -d 2 10
#sar -v 2 10
#sar -b 2 10
#sar -u 2 10
#sar -w 2 10
#vmstat 2 10
#iostat 2 10


b Monitor buffer cache
-d Monitor disk activity
-q Monitor queue length
-u Monitor CPU activity
-w Monitor swap space activity
-o Save data into a file
-f Read previously saved data from a file


http://www.blogcatalog.com/directory/technology/computers/